# vcokltfre/normalize

## A repository of letters and look-alikes to create text normalization capable filters

This repo exists because of a need to create better filters that can stand up to people using unicode characters which look similar to ascii letters to avoid filters. You are free to use this list how you like, and please contribute any alternatives that have been missed!


### Note: Although this is an installable python library the word list is 100% available for use without python, this is just so that it can be used as a python library too.
